@@ -1,4 +1,3 @@
-import pandas as pd
 import io
 
 # Reformat table_color as dict of tuples
@@ -17,30 +16,48 @@ dict_colors = {
     'green_dark' : ('#FFFFFF', '2px solid #548235', '#E2EFDA', '#548235'),
     'red_dark' : ('#FFFFFF', '2px solid #823535', '#efdada', '#823535')
 }
-        
+
+
 def build_table(
-		df, 
-		color, 
-		font_size='medium', 
-		font_family='Century Gothic, sans-serif', 
-		text_align='left', 
-		width='auto', 
-		index=False, 
-		even_color='black', 
-		even_bg_color='white', 
-		width_dict=[]):
+        df, 
+        color, 
+        font_size='medium', 
+        font_family='Century Gothic, sans-serif', 
+        text_align='left', 
+        width='auto', 
+        index=False, 
+        even_color='black', 
+        even_bg_color='white', 
+        odd_bg_color=None,
+        border_bottom_color=None,
+        escape=True,
+        width_dict=[],
+        padding="0px 20px 0px 0px",
+        float_format=None,
+        conditions={}):
 
     if df.empty:
       return ''
      
     # Set color
-    padding="0px 20px 0px 0px"
     color, border_bottom, odd_background_color, header_background_color = dict_colors[color]
 
+    if odd_bg_color:
+        odd_background_color = odd_bg_color
+
+    if border_bottom_color:
+        border_bottom = border_bottom_color 
+
     a = 0
     while a != len(df):
         if a == 0:        
-            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = index, border = 0)
+            df_html_output = df.iloc[[a]].to_html(
+                na_rep="", 
+                index=index, 
+                border=0, 
+                escape=escape, 
+                float_format=float_format,
+            )
             # change format of header
             if index:
                 df_html_output = df_html_output.replace('<th>'
@@ -85,7 +102,7 @@ def build_table(
             a = 1
 
         elif a % 2 == 0:
-            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = index, header = False)
+            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = index, header = False, escape=escape)
              
             # change format of index
             df_html_output = df_html_output.replace('<th>'
@@ -110,7 +127,7 @@ def build_table(
             a += 1       
 
         elif a % 2 != 0:
-            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = index, header = False)
+            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = index, header = False, escape=escape)
              
             # change format of index
             df_html_output = df_html_output.replace('<th>'
@@ -154,16 +171,66 @@ def build_table(
     </tr>
     <tr>""")
 
+    if conditions:
+        for k in conditions.keys():
+            try:
+                conditions[k]['index'] = list(df.columns).index(k)
+                width_body = ''
+                w = 0
+                for line in io.StringIO(body):
+                    updated_body = False
+                    if  w == conditions[k]['index']:
+                        try:
+                            if int(repr(line).split('>')[1].split('<')[0]) < conditions[k]['min']:
+                                if 'color: black' in repr(line):
+                                    width_body = width_body + repr(line).replace("color: black", 'color: ' + conditions[k]['min_color'])[1:]
+                                elif 'color: white' in repr(line):
+                                    width_body = width_body + repr(line).replace("color: white", 'color: ' + conditions[k]['min_color'])[1:]
+                                else:
+                                    width_body = width_body + repr(line).replace('">', '; color: ' + conditions[k]['min_color'] + '">')[1:]
+                                updated_body = True
+                            elif int(repr(line).split('>')[1].split('<')[0]) > conditions[k]['max']:
+                                if 'color: black' in repr(line):
+                                    width_body = width_body + repr(line).replace("color: black", 'color: ' + conditions[k]['max_color'])[1:]
+                                elif 'color: white' in repr(line):
+                                    width_body = width_body + repr(line).replace("color: white", 'color: ' + conditions[k]['max_color'])[1:]
+                                else:
+                                    width_body = width_body + repr(line).replace('">', '; color: ' + conditions[k]['max_color'] + '">')[1:]
+                                updated_body = True
+                        except:
+                            pass
+                    if not updated_body:
+                        width_body = width_body + repr(line)[1:]
+
+                    if str(repr(line))[:10] == "'      <td" or str(repr(line))[:10] == "'      <th":
+                        if w == len(df.columns) -1:
+                            w = 0
+                        else:
+                            w += 1
+                body = width_body[:len(width_body)-1]
+            except:
+                pass
 
     if len(width_dict) == len(df.columns):
         width_body = ''
         w = 0
-        for line in io.StringIO(body):
-            width_body = width_body + repr(line).replace("width: auto", 'width: ' + width_dict[w]).replace("\\n'", "")[1:]
-            if w == len(width_dict) -1:
-                w = 0
-            else:
-                w += 1
-        return width_body[:len(width_body)-1]
+        if conditions:
+            for line in body.split(r"\n'"):
+                width_body = width_body + repr(line).replace("width: auto", 'width: ' + width_dict[w])[1:]
+                if str(repr(line))[:10] == "'      <td" or str(repr(line))[:10] == "'      <th" :
+                    if w == len(df.columns) -1:
+                        w = 0
+                    else:
+                        w += 1
+        else:
+            for line in io.StringIO(body):
+                line = line.replace("\n", "")
+                width_body = width_body + repr(line).replace("width: auto", 'width: ' + width_dict[w])[1:]
+                if str(repr(line))[:10] == "'      <td" or str(repr(line))[:10] == "'      <th" :
+                    if w == len(df.columns) -1:
+                        w = 0
+                    else:
+                        w += 1
+        return width_body[:len(width_body)-1].replace("'", "")
     else:
-        return body
\ No newline at end of file
+        return body.replace(r"\n'", "")
